@@ -41,7 +41,7 @@ from IPython.core.pylabtools import print_figure
 from IPython.display import display, HTML, SVG
 
 import pyAgrum as gum
-from pyAgrum.lib.bn2graph import BN2dot, proba2histo, BNinference2dot, _proba2bgcolor
+from pyAgrum.lib.bn2graph import BN2dot, proba2histo, BNinference2dot, _proba2bgcolor, forDarkTheme, forLightTheme, getBlackInTheme
 from pyAgrum.lib.bn_vs_bn import GraphicalBNComparator
 
 _cdict = {
@@ -83,6 +83,7 @@ def configuration():
 
 
 def __insertLinkedSVGs(mainSvg):
+  re_buggwhitespace = re.compile(r"(<image [^>]*>)")
   re_images = re.compile(r"(<image [^>]*>)")
   re_xlink = re.compile(r"xlink:href=\"([^\"]*)")
   re_viewbox = re.compile(r"(viewBox=\"[^\"]*\")")
@@ -104,56 +105,60 @@ def __insertLinkedSVGs(mainSvg):
           content += line
     __fragments[secondarySvg] = (viewBox, content)
 
-  if len(__fragments) == 0:
-    return mainSvg
+  if len(__fragments) > 0:
+    # replace image tags by svg tags
+    img2svg = re.sub(r"<image ([^>]*)/>", "<svg \g<1>>", mainSvg)
 
-  # replace image tags by svg tags
-  img2svg = re.sub(r"<image ([^>]*)/>", "<svg \g<1>>", mainSvg)
+    # insert secondaries into main
+    def ___insertSecondarySvgs(matchObj):
+      vb, code = __fragments[matchObj.group(1)]
+      return vb+matchObj.group(2)+code
 
-  # insert secondaries into main
-  def ___insertSecondarySvgs(matchObj):
-    vb, code = __fragments[matchObj.group(1)]
-    return vb+matchObj.group(2)+code
+    mainSvg = re.sub(r'xlink:href="([^"]*)"(.*>)',
+                     ___insertSecondarySvgs, img2svg)
 
-  return re.sub(r'xlink:href="([^"]*)"(.*>)', ___insertSecondarySvgs, img2svg)
+  # remove buggy white-space (for notebooks)
+  mainSvg = mainSvg.replace("white-space:pre;", "")
+  return mainSvg
 
 
-def _reprGraph(gr, size, format, asString):
+def _reprGraph(gr, size, asString):
   """
   repr a pydot graph in a notebook
 
-  :param string format : render as png or create_svg
   :param string size : size of the rendered graph
   :param boolean asString : display the graph or return a string containing the corresponding HTML fragment
   """
   gr.set_size(size)
-  if format == "svg":
+  if gum.config["notebook", "graph_format"] == "svg":
     gsvg = SVG(__insertLinkedSVGs(gr.create_svg().decode('utf-8')))
     if asString:
       return gsvg.data
     else:
-      display(HTML(gsvg.data))
+      display(gsvg)
   else:
     i = Image(format="png", data=gr.create_png())
     if asString:
       return '<img style="margin:0" src="data:image/png;base64,{}"/>'.format(base64.encodebytes(i.data).decode())
     else:
-      display_png(Image(format="png", data=gr.create_png()))
+      display_png(i)
 
 
-def showGraph(gr, size="4", format='svg'):
+def showGraph(gr, size=None):
   """
   show a pydot graph in a notebook
 
   :param gr: pydot graph
   :param size:  size of the rendered graph
-  :param format: render as "png" or "svg"
   :return: the representation of the graph
   """
-  return _reprGraph(gr, size, format, asString=False)
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
+  return _reprGraph(gr, size, asString=False)
 
 
-def getGraph(gr, size="4", format='svg'):
+def getGraph(gr, size=None):
   """
   get a HTML string representation of pydot graph
 
@@ -162,36 +167,55 @@ def getGraph(gr, size="4", format='svg'):
   :param format: render as "png" or "svg"
   :return: the HTML representation of the graph as a string
   """
-  return _reprGraph(gr, size, format, asString=True)
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+  return _reprGraph(gr, size, asString=True)
 
 
-def showDot(dotstring, size="4", format='svg'):
+def _from_dotstring(dotstring):
+  g = dot.graph_from_dot_data(dotstring)
+  g.set_bgcolor("transparent")
+  for e in g.get_edges():
+    if e.get_color() is None:
+      e.set_color(getBlackInTheme())
+  for n in g.get_nodes():
+    if n.get_color() is None:
+      n.set_color(getBlackInTheme())
+    if n.get_fontcolor() is None:
+      n.set_fontcolor(getBlackInTheme())
+  return g
+
+
+def showDot(dotstring, size=None):
   """
   show a dot string as a graph
 
   :param dotstring: dot string
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
   :return: the representation of the graph
   """
-  return showGraph(dot.graph_from_dot_data(dotstring), size, format)
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+  return showGraph(_from_dotstring(dotstring), size)
 
 
-def getDot(dotstring, size="4", format='svg'):
+def getDot(dotstring, size=None):
   """
   get a dot string as a HTML string
 
   :param dotstring: dot string
   :param size: size of the rendered graph
   :param format: render as "png" or "svg"
+  :param bg: color for background
   :return: the HTML representation of the graph
   """
-  g = dot.graph_from_dot_data(dotstring)
-  g.set_bgcolor("transparent")
-  return getGraph(g, size, format)
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
+  return getGraph(_from_dotstring(dotstring), size)
 
 
-def getBNDiff(bn1, bn2, size="4", format='svg'):
+def getBNDiff(bn1, bn2, size=None):
   """ get a HTML string representation of a graphical diff between the arcs of _bn1 (reference) with those of _bn2.
 
   * full black line: the arc is common for both
@@ -202,13 +226,14 @@ def getBNDiff(bn1, bn2, size="4", format='svg'):
   :param BayesNet bn1: referent model for the comparison
   :param BayesNet bn2: bn compared to the referent model
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
   cmp = GraphicalBNComparator(bn1, bn2)
-  return getGraph(cmp.dotDiff(), size, format)
+  return getGraph(cmp.dotDiff(), size)
 
 
-def showBNDiff(bn1, bn2, size="4", format='svg'):
+def showBNDiff(bn1, bn2, size=None):
   """ show a graphical diff between the arcs of _bn1 (reference) with those of _bn2.
 
   * full black line: the arc is common for both
@@ -219,70 +244,127 @@ def showBNDiff(bn1, bn2, size="4", format='svg'):
   :param BayesNet bn1: referent model for the comparison
   :param BayesNet bn2: bn compared to the referent model
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
   cmp = GraphicalBNComparator(bn1, bn2)
-  showGraph(cmp.dotDiff(), size, format)
+  showGraph(cmp.dotDiff(), size)
 
 
-def showJunctionTree(bn, withNames=True, size="4", format='svg'):
+def showJunctionTree(bn, withNames=True, size=None):
   """
   Show a junction tree
 
   :param bn: the bayesian network
   :param boolean withNames: display the variable names or the node id in the clique
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
   :return: the representation of the graph
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
   jtg = gum.JunctionTreeGenerator()
   jt = jtg.junctionTree(bn)
   if withNames:
-    return showDot(jt.toDotWithNames(bn), size, format)
+    return showDot(jt.toDotWithNames(bn), size)
   else:
-    return showDot(jt.toDot(), size, format)
+    return showDot(jt.toDot(), size)
 
 
-def getJunctionTree(bn, withNames=True, size="4", format='svg'):
+def getJunctionTree(bn, withNames=True, size=None):
   """
   get a HTML string for a junction tree (more specifically a join tree)
 
   :param bn: the bayesian network
   :param boolean withNames: display the variable names or the node id in the clique
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
   :return: the HTML representation of the graph
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
   jtg = gum.JunctionTreeGenerator()
   jt = jtg.junctionTree(bn)
   if withNames:
-    return getDot(jt.toDotWithNames(bn), size, format)
+    return getDot(jt.toDotWithNames(bn), size)
   else:
-    return getDot(jt.toDot(), size, format)
+    return getDot(jt.toDot(), size)
 
 
-def showInfluenceDiagram(diag, size="4", format='svg'):
+def _infdiag_todot(diag):
+  res = "digraph {"
+
+  # chance node
+  res += '''
+    node [fillcolor="{}",
+          fontcolor="{}",
+          style=filled,shape={}];
+  ''' .format(gum.config["influenceDiagram", "default_chance_bgcolor"],
+              gum.config["influenceDiagram", "default_chance_fgcolor"],
+              gum.config["influenceDiagram", "default_chance_shape"])
+  for node in diag.ids():
+    if diag.isChanceNode(node):
+      res += '   "'+diag.variable(node).name()+'";'+"\n"
+
+  # decision node
+  res += '''
+    node [fillcolor="{}",
+          fontcolor="{}",
+          style=filled,shape={}];
+  ''' .format(gum.config["influenceDiagram", "default_decision_bgcolor"],
+              gum.config["influenceDiagram", "default_decision_fgcolor"],
+              gum.config["influenceDiagram", "default_decision_shape"])
+  for node in diag.ids():
+    if diag.isDecisionNode(node):
+      res += '   "'+diag.variable(node).name()+'";'+"\n"
+
+  # utility node
+  res += '''
+    node [fillcolor="{}",
+          fontcolor="{}",
+          style=filled,shape={}];
+  ''' .format(gum.config["influenceDiagram", "default_utility_bgcolor"],
+              gum.config["influenceDiagram", "default_utility_fgcolor"],
+              gum.config["influenceDiagram", "default_utility_shape"])
+  for node in diag.ids():
+    if diag.isUtilityNode(node):
+      res += '   "'+diag.variable(node).name()+'";'+"\n"
+
+  # arcs
+  res += "\n"
+  for node in diag.ids():
+    for chi in diag.children(node):
+      res += '  "'+diag.variable(node).name()+'"->"'+diag.variable(chi).name()+'";'+"\n"
+  res += "}"
+  return res
+
+
+def showInfluenceDiagram(diag, size=None):
   """
   show an influence diagram as a graph
 
   :param diag: the influence diagram
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
   :return: the representation of the influence diagram
   """
-  return showDot(diag.toDot(), size, format)
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
+  return showDot(_infdiag_todot(diag), size)
 
 
-def getInfluenceDiagram(diag, size="4", format='svg'):
+def getInfluenceDiagram(diag, size=None):
   """
   get a HTML string for an influence diagram as a graph
 
   :param diag: the influence diagram
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
   :return: the HTML representation of the influence diagram
   """
-  return getDot(diag.toDot(), size, format)
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
+  return getDot(_infdiag_todot(diag), size)
 
 
 def showProba(p, scale=1.0):
@@ -293,13 +375,16 @@ def showProba(p, scale=1.0):
   :return:
   """
   fig = proba2histo(p, scale)
+  fig.patch.set_facecolor(gum.config["notebook", "figure_facecolor"])
+  IPython.display.set_matplotlib_formats(
+      gum.config["notebook", "graph_format"])
   plt.show()
 
 
-def _saveFigProba(p, filename, format="svg"):
+def _saveFigProba(p, filename):
   fig = proba2histo(p)
   fig.savefig(filename, bbox_inches='tight', transparent=True,
-              pad_inches=0, dpi=fig.dpi, format=format)
+              pad_inches=0, dpi=fig.dpi, format=gum.config["notebook", "graph_format"])
   plt.close(fig)
 
 
@@ -370,43 +455,41 @@ def showApproximationScheme(apsc, scale=np.log10):
     else:
       plt.xlim(1, len(apsc.history()))
     plt.title(
-        "{0} \n Time : {1} s | Iterations : {2} | Espilon : {3}".format(x, apsc.currentTime(), apsc.nbrIterations(),
-                                                                        apsc.epsilon()))
+        "Time : {} s | Iterations : {} | Espilon : {}".format(apsc.currentTime(),
+                                                              apsc.nbrIterations(),
+                                                              apsc.epsilon()))
     plt.plot(scale(apsc.history()), 'g')
-  else:
-    ie2.messageApproximationScheme()
 
 
-def showBN(bn, size="4", format="svg", nodeColor=None, arcWidth=None, arcColor=None, cmap=None, cmapArc=None):
+def showBN(bn, size=None, nodeColor=None, arcWidth=None, arcColor=None, cmap=None, cmapArc=None):
   """
   show a Bayesian network
 
   :param bn: the bayesian network
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
-  :param nodeColor: a nodeMap of values (between 0 and 1) to be shown as color of nodes (with special colors for 0
-  and 1)
+  :param nodeColor: a nodeMap of values (between 0 and 1) to be shown as color of nodes (with special colors for 0 and 1)
   :param arcWidth: a arcMap of values to be shown as width of arcs
   :param arcColor: a arcMap of values (between 0 and 1) to be shown as color of arcs
   :param cmap: color map to show the colors
   :param cmapArc: color map to show the arc color if distinction is needed
   :return: the graph
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
   if cmapArc is None:
     cmapArc = cmap
 
-  return showGraph(BN2dot(bn, size, nodeColor, arcWidth, arcColor, cmap, cmapArc), size, format)
+  return showGraph(BN2dot(bn, size, nodeColor, arcWidth, arcColor, cmap, cmapArc), size)
 
 
-def getBN(bn, size="4", format="svg", nodeColor=None, arcWidth=None, arcColor=None, cmap=None, cmapArc=None):
+def getBN(bn, size=None, nodeColor=None, arcWidth=None, arcColor=None, cmap=None, cmapArc=None):
   """
   get a HTML string for a Bayesian network
 
   :param bn: the bayesian network
   :param size: size of the rendered graph
-  :param format: render as "png" or "svg"
-  :param nodeColor: a nodeMap of values (between 0 and 1) to be shown as color of nodes (with special colors for 0
-  and 1)
+  :param nodeColor: a nodeMap of values (between 0 and 1) to be shown as color of nodes (with special colors for 0 and 1)
   :param arcWidth: a arcMap of values to be shown as width of arcs
   :param arcColor: a arcMap of values (between 0 and 1) to be shown as color of arcs
   :param cmap: color map to show the colors
@@ -414,10 +497,13 @@ def getBN(bn, size="4", format="svg", nodeColor=None, arcWidth=None, arcColor=No
 
   :return: the graph
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
   if cmapArc is None:
     cmapArc = cmap
 
-  return getGraph(BN2dot(bn, size, nodeColor, arcWidth, arcColor, cmap, cmapArc), size, format)
+  return getGraph(BN2dot(bn, size, nodeColor, arcWidth, arcColor, cmap, cmapArc), size)
 
 
 def _normalizeVals(vals, hilightExtrema=False):
@@ -498,7 +584,7 @@ def _reprInformation(bn, evs, size, cmap, asString):
     return display(HTML(sss))
 
 
-def getInformation(bn, evs=None, size="4", cmap=_INFOcmap):
+def getInformation(bn, evs=None, size=None, cmap=_INFOcmap):
   """
   get a HTML string for a bn annoted with results from inference : entropy and mutual informations
 
@@ -508,13 +594,16 @@ def getInformation(bn, evs=None, size="4", cmap=_INFOcmap):
   :param cmap: colour map used
   :return: the HTML string
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_size"]
+
   if evs is None:
     evs = {}
 
   return _reprInformation(bn, evs, size, cmap, asString=True)
 
 
-def showInformation(bn, evs=None, size="4", cmap=_INFOcmap):
+def showInformation(bn, evs=None, size=None, cmap=_INFOcmap):
   """
   show a bn annoted with results from inference : entropy and mutual informations
 
@@ -530,8 +619,7 @@ def showInformation(bn, evs=None, size="4", cmap=_INFOcmap):
   return _reprInformation(bn, evs, size, cmap, asString=False)
 
 
-def showInference(bn, engine=None, evs=None, targets=None, size="7", format='svg', nodeColor=None, arcWidth=None,
-                  cmap=None):
+def showInference(bn, engine=None, evs=None, targets=None, size=None,  nodeColor=None, arcWidth=None, arcColor=None, cmap=None, cmapArc=None, dag=None):
   """
   show pydot graph for an inference in a notebook
 
@@ -540,21 +628,28 @@ def showInference(bn, engine=None, evs=None, targets=None, size="7", format='svg
   :param dictionnary evs: map of evidence
   :param set targets: set of targets
   :param string size: size of the rendered graph
-  :param string format: render as "png" or "svg"
-  :param boolean asString: display the graph or return a string containing the corresponding HTML fragment
+  :param nodeColor: a nodeMap of values (between 0 and 1) to be shown as color of nodes (with special colors for 0 and 1)
+  :param arcWidth: a arcMap of values to be shown as width of arcs
+  :param arcColor: a arcMap of values (between 0 and 1) to be shown as color of arcs
+  :param cmap: color map to show the color of nodes and arcs
+  :param cmapArc: color map to show the vals of Arcs.
+  :param dag : only shows nodes that have their id in the dag (and not in the whole BN)
+
   :return: the desired representation of the inference
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_inference_size"]
+
   if evs is None:
     evs = {}
 
   if targets is None:
     targets = {}
 
-  return showGraph(BNinference2dot(bn, size, engine, evs, targets, format, nodeColor, arcWidth, cmap), size, format)
+  return showGraph(BNinference2dot(bn, size, engine, evs, targets, nodeColor, arcWidth, arcColor, cmap, cmapArc, dag), size)
 
 
-def getInference(bn, engine=None, evs=None, targets=None, size="7", format='svg', nodeColor=None, arcWidth=None,
-                 cmap=None):
+def getInference(bn, engine=None, evs=None, targets=None, size=None,  nodeColor=None, arcWidth=None, arcColor=None, cmap=None, cmapArc=None, dag=None):
   """
   get a HTML string for an inference in a notebook
 
@@ -563,20 +658,25 @@ def getInference(bn, engine=None, evs=None, targets=None, size="7", format='svg'
   :param dictionnary evs: map of evidence
   :param set targets: set of targets
   :param string size: size of the rendered graph
-  :param string format: render as "png" or "svg"
-  :param nodeColor: a nodeMap of values (between 0 and 1) to be shown as color of nodes (with special colors for 0
-  and 1)
+  :param nodeColor: a nodeMap of values (between 0 and 1) to be shown as color of nodes (with special colors for 0 and 1)
   :param arcWidth: a arcMap of values to be shown as width of arcs
+  :param arcColor: a arcMap of values (between 0 and 1) to be shown as color of arcs
   :param cmap: color map to show the color of nodes and arcs
+  :param cmapArc: color map to show the vals of Arcs.
+  :param dag : only shows nodes that have their id in the dag (and not in the whole BN)
+
   :return: the desired representation of the inference
   """
+  if size is None:
+    size = gum.config["notebook", "default_graph_inference_size"]
+
   if evs is None:
     evs = {}
 
   if targets is None:
     targets = {}
 
-  return getGraph(BNinference2dot(bn, size, engine, evs, targets, format, nodeColor, arcWidth, cmap), size, format)
+  return getGraph(BNinference2dot(bn, size, engine, evs, targets,  nodeColor, arcWidth, arcColor, cmap, cmapArc), size)
 
 
 def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False):
@@ -603,14 +703,16 @@ def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False
       r = int(255 - val * 128)
       g = int(127 + val * 128)
       b = 100
-      s += "background-color:" + _rgb(r, g, b) + ";"
-    s += "text-align:right;'>{:." + str(digits) + "f}</td>"
+      s += "color:black;background-color:" + _rgb(r, g, b) + ";"
+    s += "text-align:right;'>{:." + \
+        gum.config['notebook', 'potential_visible_digits'] + "f}</td>"
     return s.format(val)
 
   html = list()
-  html.append("<table>")
+  html.append('<table style="border:1px solid black;">')
   if pot.empty():
-    html.append("<tr><th style='background-color:#AAAAAA'>&nbsp;</th></tr>")
+    html.append(
+        "<tr><th>&nbsp;</th></tr>")
     html.append("<tr>" + _mkCell(pot.get(gum.Instantiation())) + "</tr>")
   else:
     if varnames is not None and len(varnames) != pot.nbrDim():
@@ -624,24 +726,28 @@ def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False
     # first line
     if nparents > 0:
       html.append(
-          "<tr><th colspan='{}'></th><th colspan='{}' style='background-color:#AAAAAA'><center>{"
+          "<tr><th colspan='{}'></th><th colspan='{}' style='border:1px solid black;color:black;background-color:#808080;'><center>{"
           "}</center></th></tr>".format(
               nparents, var.domainSize(), varname))
     else:
       html.append(
-          "<tr style='background-color:#AAAAAA'><th colspan='{}'><center>{}</center></th></tr>".format(
+          "<tr style='border:1px solid black;color:black;background-color:#808080'><th colspan='{}'><center>{}</center></th></tr>".format(
               var.domainSize(),
               varname))
     # second line
     s = "<tr>"
     if nparents > 0:
-      # for parent in pot.var_names[:-1] if varnames == None else varnames[1:]:
-      for par in range(nparents - 1, 0 - 1, -1):
+      # parents order
+      if gum.config["notebook", "potential_parent_values"] == "revmerge":
+        pmin, pmax, pinc = nparents - 1, 0 - 1, -1
+      else:
+        pmin, pmax, pinc = 0, nparents, 1
+      for par in range(pmin, pmax, pinc):
         parent = pot.var_names[par] if varnames is None else varnames[par]
-        s += "<th style='background-color:#AAAAAA'><center>{}</center></th>".format(
+        s += "<th style='border:1px solid black;color:black;background-color:#808080'><center>{}</center></th>".format(
             parent)
     for label in var.labels():
-      s += "<th style='background-color:#BBBBBB'><center>{}</center></th>".format(
+      s += "<th style='border:1px solid black;border-bottom-style: double;color:black;background-color:#BBBBBB'><center>{}</center></th>".format(
           label)
     s += '</tr>'
 
@@ -657,15 +763,20 @@ def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False
     inst.setFirst()
     while not inst.end():
       s = "<tr>"
-      for par in range(1, nparents + 1):
+      # parents order
+      if gum.config["notebook", "potential_parent_values"] == "revmerge":
+        pmin, pmax, pinc = 1, nparents + 1, 1
+      else:
+        pmin, pmax, pinc = nparents, 0, -1
+      for par in range(pmin, pmax, pinc):
         label = inst.variable(par).label(inst.val(par))
-        if par == 1:
-          s += "<th style='background-color:#BBBBBB'><center>{}</center></th>".format(
+        if par == 1 or gum.config["notebook", "potential_parent_values"] == "nomerge":
+          s += "<th style='border:1px solid black;color:black;background-color:#BBBBBB'><center>{}</center></th>".format(
               label)
         else:
           if sum([inst.val(i) for i in range(1, par)]) == 0:
-            s += "<th style='background-color:#BBBBBB;' rowspan = '{}'><center>{}</center></th>".format(offset[par],
-                                                                                                        label)
+            s += "<th style='border:1px solid black;color:black;background-color:#BBBBBB;' rowspan = '{}'><center>{}</center></th>".format(
+                offset[par], label)
       for j in range(pot.variable(0).domainSize()):
         s += _mkCell(pot.get(inst))
         inst.inc()
@@ -686,13 +797,25 @@ def __isKindOfProba(pot):
   :param pot: the potential
   :return: True or False
   """
-  if abs(pot.sum() - 1) < 1e-2:
+  epsilon = 1e-5
+  if pot.min() < -epsilon:
+    return False
+  if pot.max() > 1 + epsilon:
+    return False
+
+  # is it a joint proba ?
+  if abs(pot.sum() - 1) < epsilon:
     return True
 
-  q = pot.margSumOut([pot.variable(0).name()])
-  if abs(q.max() - 1) > 1e-2:
+  # marginal and then not proba (because of the test just above)
+  if pot.nbrDim() < 2:
     return False
-  if abs(q.min() - 1) > 1e-2:
+
+  # is is a CPT ?
+  q = pot.margSumOut([pot.variable(0).name()])
+  if abs(q.max() - 1) > epsilon:
+    return False
+  if abs(q.min() - 1) > epsilon:
     return False
   return True
 
@@ -711,7 +834,8 @@ def showPotential(pot, digits=4, withColors=None, varnames=None):
   if withColors is None:
     withColors = __isKindOfProba
 
-  display(_reprPotential(pot, digits, withColors, varnames, asString=False))
+  display(_reprPotential(
+      pot, digits, withColors, varnames, asString=False))
 
 
 def getPotential(pot, digits=4, withColors=None, varnames=None):
@@ -834,6 +958,8 @@ def getInferenceEngine(ie, inferenceCaption):
 
 # adding _repr_html_ to some pyAgrum classes !
 gum.BayesNet._repr_html_ = lambda self: getBN(self)
+gum.BayesNetFragment._repr_html_ = lambda self: getBN(self)
+
 gum.Potential._repr_html_ = lambda self: getPotential(self)
 gum.LazyPropagation._repr_html_ = lambda self: getInferenceEngine(
     self, "Lazy Propagation on this BN")
@@ -847,4 +973,5 @@ gum.EssentialGraph._repr_html_ = lambda self: getDot(self.toDot())
 gum.MarkovBlanket._repr_html_ = lambda self: getDot(self.toDot())
 
 
-IPython.display.set_matplotlib_formats('svg')
\ No newline at end of file
+mpl.rcParams['figure.facecolor'] = gum.config["notebook", "figure_facecolor"]
+IPython.display.set_matplotlib_formats(gum.config["notebook", "graph_format"])
